CREATE DATABASE IF NOT EXISTS testblog CHARACTER SET=utf8 COLLATE=utf8_general_ci;
USE testblog;

DROP TABLE IF EXISTS `LJ_Comments_usermaps`;
DROP TABLE IF EXISTS `LJ_Comments_metadata`;
DROP TABLE IF EXISTS `LJ_Comments`;
DROP TABLE IF EXISTS `LJ_Posts`;
DROP TABLE IF EXISTS `SpamFilters`;
DROP TABLE IF EXISTS `Tags2Posts`;
DROP TABLE IF EXISTS `Tags`;
DROP TABLE IF EXISTS `Comments`;
DROP TABLE IF EXISTS `Posts`;
DROP TABLE IF EXISTS `Users`;

CREATE TABLE `Users` (
  `ID` int(10) unsigned NOT NULL auto_increment,
  `Username` varchar(255) NOT NULL,
  `Fullname` varchar(255) NOT NULL,
  `EMail` varchar(255) NOT NULL,
  `Password` varchar(32) NOT NULL,
  `Status` tinyint(1) NOT NULL,
  `PHPSession` varchar(255) NOT NULL,
  `LastAccess` datetime NOT NULL,
  `LJ_username` varchar(255) NOT NULL,
  `LJ_password` varchar(32) NOT NULL,
  PRIMARY KEY  (`ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `Users` (`Username`,`Fullname`,`Password`,`Status`) VALUES ('admin','admin',MD5('adminpassword'),'9');

CREATE TABLE `Posts` (
  `ID` int(10) unsigned NOT NULL auto_increment,
  `User_ID` int(10) unsigned NOT NULL,
  `Title` varchar(255) NOT NULL,
  `Content` text NOT NULL,
  `PostStatus` tinyint(1) unsigned NOT NULL,
  `CommentsStatus` tinyint(1) NOT NULL,
  `Subscribe` tinyint(1) NOT NULL,
  `LJ_Post_ID` varchar(255) NOT NULL,
  `LJ_URL` varchar(255) NOT NULL,
  `CreatedOn` datetime NOT NULL,
  PRIMARY KEY  (`ID`),
  KEY `FK_Posts_User_ID` (`User_ID`),
  CONSTRAINT `FK_Posts_User_ID` FOREIGN KEY (`User_ID`) REFERENCES `Users` (`ID`),
  INDEX `CreatedOn` (`CreatedOn`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Comments` (
  `ID` int(10) unsigned NOT NULL auto_increment,
  `Post_ID` int(10) unsigned NOT NULL,
  `Parent_ID` int(10) unsigned NOT NULL,
  `Author` varchar(255) NOT NULL,
  `EMail` varchar(255) NOT NULL,
  `Content` text NOT NULL,
  `Status` tinyint(1) NOT NULL,
  `Subscribe` tinyint(1) NOT NULL,
  `IP_address` varchar(15) NOT NULL,
  `Agent` varchar(255) NOT NULL,
  `CreatedOn` datetime NOT NULL,
  PRIMARY KEY  (`ID`),
  KEY `FK_Comments_Post_ID` (`Post_ID`),
  CONSTRAINT `FK_Comments_Post_ID` FOREIGN KEY (`Post_ID`) REFERENCES `Posts` (`ID`) ON DELETE CASCADE ON UPDATE CASCADE,
  INDEX `CreatedOn` (`CreatedOn`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `SpamFilters` (
  `ID` int(10) unsigned NOT NULL auto_increment,
  `Keyword` varchar(255) NOT NULL,
  `Type` tinyint(1) unsigned NOT NULL,
  PRIMARY KEY  (`ID`),
  INDEX `Keyword` (`Keyword`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Tags` (
  `ID` int(10) unsigned NOT NULL auto_increment,
  `Tag` varchar(255) NOT NULL,
  PRIMARY KEY  (`ID`),
  KEY `Tag` (`Tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `Tags2Posts` (
  `Tag_ID` int(10) unsigned NOT NULL,
  `Post_ID` int(10) unsigned NOT NULL,
  PRIMARY KEY  (`Tag_ID`,`Post_ID`),
  KEY `FK_Tags2Posts_Post_ID` (`Post_ID`),
  CONSTRAINT `FK_Tags2Posts_Post_ID` FOREIGN KEY (`Post_ID`) REFERENCES `Posts` (`ID`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `FK_Tags2Posts_Tag_ID` FOREIGN KEY (`Tag_ID`) REFERENCES `Tags` (`ID`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `LJ_Posts` (
  `lj_post_id` int(10) unsigned NOT NULL auto_increment,
  `blog_post_id` int(10) unsigned NOT NULL,
  `eventtime` datetime NOT NULL,
  `subject` varchar(255) NOT NULL,
  `event` text NOT NULL,
  `taglist` text NOT NULL,
  `action` varchar(1) NOT NULL,
  `security` varchar(255) NOT NULL,
  `url` varchar(255) NOT NULL,
  PRIMARY KEY  (`lj_post_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `LJ_Comments` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `posterid` int(10) unsigned NOT NULL,
  `state` varchar(1) NOT NULL,
  `jitemid` int(10) unsigned NOT NULL,
  `parentid` int(10) unsigned NOT NULL,
  `subject` varchar(255) NOT NULL,
  `body` text NOT NULL,
  `date` datetime NOT NULL,
  PRIMARY KEY  (`ID`),
  INDEX `jitemid` (`jitemid`),
  INDEX `date` (`date`),
  INDEX `posterid` (`posterid`),
  INDEX `parentid` (`parentid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `LJ_Comments_metadata` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `posterid` int(10) unsigned NOT NULL,
  `state` varchar(1) NOT NULL,
  PRIMARY KEY  (`ID`),
  INDEX `posterid` (`posterid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `LJ_Comments_usermaps` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `user` varchar(255) NOT NULL,
  PRIMARY KEY  (`ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
